@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2020-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -76,12 +76,14 @@ QString ExportAddressbookJobInterfaceTestImpl::resourcePath(const QString &agent
 
 void ExportAddressbookJobInterfaceTestImpl::backupAddressBookResourceFile(const QString &agentIdentifier, const QString &defaultPath)
 {
-    auto *job = new TestBackupResourceFileJob(this);
-    job->setDefaultPath(defaultPath);
-    job->setIdentifier(agentIdentifier);
-    job->setTestPath(mPathConfig);
-    job->setZip(archive());
-    connect(job, &TestBackupResourceFileJob::error, this, &ExportAddressbookJobInterfaceTestImpl::error);
-    connect(job, &TestBackupResourceFileJob::info, this, &ExportAddressbookJobInterfaceTestImpl::info);
-    job->start();
+  auto job = new TestBackupResourceFileJob(this);
+  job->setDefaultPath(defaultPath);
+  job->setIdentifier(agentIdentifier);
+  job->setTestPath(mPathConfig);
+  job->setZip(archive());
+  connect(job, &TestBackupResourceFileJob::error, this,
+          &ExportAddressbookJobInterfaceTestImpl::error);
+  connect(job, &TestBackupResourceFileJob::info, this,
+          &ExportAddressbookJobInterfaceTestImpl::info);
+  job->start();
 }
