@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2020-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -36,7 +36,8 @@ void ImportAkregatorJobInterfaceTest::importAkegator()
     TestImportFile *file = new TestImportFile(zipFilePath + testPath, this);
     file->setPathConfig(zipFilePath + testPath);
     file->setExtractPath(QDir::tempPath() + testPath);
-    auto *impl = new ImportAkregatorJobInterfaceTestImpl(this, options, file->archiveStorage(), 1);
+    auto impl = new ImportAkregatorJobInterfaceTestImpl(
+        this, options, file->archiveStorage(), 1);
     file->setAbstractImportExportJob(impl);
     file->start();
     delete impl;
