@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2020-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -62,21 +62,27 @@ bool GenerateListFileFromArchive::searchArchiveElement(const QString &path, cons
 
 void GenerateListFileFromArchive::addSubItems(const QString &topLevelPath, const KArchiveEntry *entry, int indent, const QString &fullpath)
 {
-    const auto *dir = static_cast<const KArchiveDirectory *>(entry);
-    const QString space = QString(indent * 2, QLatin1Char(' '));
-    const QStringList lst = dir->entries();
-    for (const QString &entryName : lst) {
-        const KArchiveEntry *entry = dir->entry(entryName);
-        if (entry) {
-            if (entry->isDirectory()) {
-                const auto *dirEntry = static_cast<const KArchiveDirectory *>(entry);
-                //mListFile += space + dirEntry->name();
-                addSubItems(topLevelPath, entry, indent, (fullpath.isEmpty() ? QString() : fullpath + QLatin1Char('/')) + dirEntry->name());
-            } else if (entry->isFile()) {
-                const auto *file = static_cast<const KArchiveFile *>(entry);
-                const QString fileFullPath = topLevelPath + (fullpath.isEmpty() ? QString() : fullpath + QLatin1Char('/')) + file->name();
-                mListFile += space + fileFullPath;
-            }
-        }
+  const auto dir = static_cast<const KArchiveDirectory *>(entry);
+  const QString space = QString(indent * 2, QLatin1Char(' '));
+  const QStringList lst = dir->entries();
+  for (const QString &entryName : lst) {
+    const KArchiveEntry *entry = dir->entry(entryName);
+    if (entry) {
+      if (entry->isDirectory()) {
+        const auto dirEntry = static_cast<const KArchiveDirectory *>(entry);
+        // mListFile += space + dirEntry->name();
+        addSubItems(
+            topLevelPath, entry, indent,
+            (fullpath.isEmpty() ? QString() : fullpath + QLatin1Char('/')) +
+                dirEntry->name());
+      } else if (entry->isFile()) {
+        const auto file = static_cast<const KArchiveFile *>(entry);
+        const QString fileFullPath =
+            topLevelPath +
+            (fullpath.isEmpty() ? QString() : fullpath + QLatin1Char('/')) +
+            file->name();
+        mListFile += space + fileFullPath;
+      }
     }
+  }
 }
