@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2020-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -42,7 +42,7 @@ void BackupResourceFileJobBase::start()
             if (fileAdded) {
                 Q_EMIT info(i18n("\"%1\" was backed up.", filename));
 
-                auto *job = new StoreResourceJob(this);
+                auto job = new StoreResourceJob(this);
                 connect(job, &StoreResourceJob::error, this, &BackupResourceFileJobBase::error);
                 connect(job, &StoreResourceJob::info, this, &BackupResourceFileJobBase::info);
                 job->setArchivePath(archivePath);
