@@ -4,8 +4,7 @@
    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef ExportMailJobINTERFACE_H
-#define ExportMailJobINTERFACE_H
+#pragma once
 
 #include "abstractimportexportjob.h"
 #include "pimdataexportercore_private_export.h"
@@ -60,4 +59,3 @@ private:
     int mIndexIdentifier = 0;
 };
 
-#endif // ExportMailJob_H
