@@ -4,8 +4,7 @@
    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef SYNCHRONIZERESOURCEJOB_H
-#define SYNCHRONIZERESOURCEJOB_H
+#pragma once
 
 #include <QObject>
 #include <QStringList>
@@ -36,4 +35,3 @@ private:
     bool mOnlyCollection = true;
 };
 
-#endif // SYNCHRONIZERESOURCEJOB_H
